@@ -116,8 +116,8 @@ void KMyListBox::addDirName( const KURL & dirname )
 bool KMyListBox::isFile( const KURL & f, bool autoadd )
 {
     UDSEntry entry;
-    
-    NetAccess::stat( f, entry );
+
+    NetAccess::stat(f, entry, 0);
     KFileItem file( entry, f );
     if( !file.isReadable() )
         return false;
@@ -837,3 +837,4 @@ TQString KMyListBoxItem::text() const
 bool KMyListBoxItem::m_preview = false;
 bool KMyListBoxItem::m_name = false;
 
+#include "kmylistbox.moc"
